package
Version:
v0.8.5
Opens a new window with list of versions in this module.
Published: Jan 16, 2025
License: MulanPSL-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DbCfg struct {
Addr string `yaml:"addr" json:"addr"`
Port int `yaml:"port" json:"port"`
User string `yaml:"user" json:"user"`
Pass string `yaml:"pass" json:"pass"`
Schema string `yaml:"schema" json:"schema"`
}
func NewMySqlDbCfg() *DbCfg
const (
DriverNone Driver = iota
DriverMySql
DriverUnsupported
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.